==> omdox-0.1.3.alpha.tar.gz: omdox-0.1.3.alpha/README.md <==
## OMDOX

OMDOX is a lightweight documentation builder that utilises [jinja2][0] templates as placeholders for markdown and code.

Code samples are parsed with [pygments][1] and the content is parsed with markdown.

You're in total control of how it looks, feels and responds to different devices.

No magic, it's plain ol' html with a dash of jinja, markdown and pygments. 

## Features

### code

Any blocks of code inside code tags are parsed; eg

```<code lang="bash">
pip install omdox
</code>```


An attempt is made to match the lang attribute against [known pygments lexers][2]. If no match is found it defaults to python.

### Markdown 

Any content inside of ...

```{% markdown %} stuff to mark down  {% endmarkdown%} ```

... gets marked down.



## Installation

```pip install omdox```

## Usage

1. Make folder for docs
2. Create layout.html inside of docs folder
2. Style as you see fit
3. Create pages that inherit layout.html in docs
5. cd 'docs'
6. run ``omdox``

Your documentation will now be in <docs>/_build

## What about static media?

Proceed as you would building a a normal site. Folders inside of `docs/` get copied into the final build. Just make sure to use relative paths in your html & css.

## Status

Early alpha.

## Issues

Create an issue, I'll be all over it like warm butter on hot bread.

## Known caveats

### Nested Folders

Doesn't support nested folders for docs so `docs/about/this.html` doesn't work. This will get fixed later on.

### Writing Documentation 

OMDOC will not make you better at writing documentation, only practice will.
[0]: http://jinja.pocoo.org/docs/
[1]: http://pygments.org/
[2]: http://pygments.org/docs/lexers/

==> omdox-0.3.0.alpha.tar.gz: omdox-0.3.0.alpha/README.md <==
## OMDOX

OMDOX is a lightweight documentation builder that utilises [jinja2][0] templates as placeholders for markdown and code.

Code samples are parsed with [pygments][1] and the content is parsed with markdown.

You're in total control of how it looks, feels and responds to different devices.

No magic, it's plain ol' html with a dash of jinja, markdown and pygments. 

## Features

### Markdown 

All content inside of the {% block content %} is parsed as markdown.


### code


Any blocks of code inside code tags are parsed; eg


```<code lang="bash">
pip install omdox
</code>```


An attempt is made to match the lang attribute against [known pygments lexers][2]. If no match is found it defaults to python.



## Installation

```pip install omdox```

## Usage

1. Make folder for docs
2. Create layout.html inside of docs folder
2. Style as you see fit
3. Create pages that inherit layout.html in docs
5. cd 'docs'
6. run ``omdox``

Your documentation will now be in <docs>/_build

## What about static media?

Proceed as you would building a a normal site. Folders inside of `docs/` get copied into the final build. Just make sure to use relative paths in your html & css.

## Status

Early alpha.

## Issues

Create an issue, I'll be all over it like warm butter on hot bread.

## Known caveats

### Nested Folders

Doesn't support nested folders for docs so `docs/about/this.html` doesn't work. This will get fixed later on.

### Writing Documentation 

OMDOX will not make you better at writing documentation, only practice will.

[0]: http://jinja.pocoo.org/docs/
[1]: http://pygments.org/
[2]: http://pygments.org/docs/lexers/
